We use some tools from the RNAstructure package [1]

- ct2dot: Converts predicted interactions in CT format to dot-bracket notation
- draw: use dot-bracket notation to plot circular representations in .svg format

[1] Reuter, J.S. and Mathews, D.H. "RNAstructure: software for RNA secondary structure prediction and analysis." BMC Bioinformatics, 11:129. (2010).
